==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/ResourceGuardProxyBaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property description
 * @property lastUpdatedTime
 * @property resourceGuardOperationDetails
 * @property resourceGuardResourceId
 */
public data class ResourceGuardProxyBaseArgs(
    public val description: Output<String>? = null,
    public val lastUpdatedTime: Output<String>? = null,
    public val resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null,
    public val resourceGuardResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs =
        com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .lastUpdatedTime(lastUpdatedTime?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationDetails(
                resourceGuardOperationDetails?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .resourceGuardResourceId(resourceGuardResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardProxyBaseArgs].
 */
@PulumiTagMarker
public class ResourceGuardProxyBaseArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var lastUpdatedTime: Output<String>? = null

    private var resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null

    private var resourceGuardResourceId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("tykbmmrwmmrmxukk")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("fgxnxujahkahklsf")
    public suspend fun lastUpdatedTime(`value`: Output<String>) {
        this.lastUpdatedTime = value
    }

    /**
     * @param value
     */
    @JvmName("cvogiutuuxuavgeb")
    public suspend
    fun resourceGuardOperationDetails(`value`: Output<List<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = value
    }

    @JvmName("ypmrkgyxcwybioiw")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: Output<ResourceGuardOperationDetailArgs>,
    ) {
        this.resourceGuardOperationDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("qohfqyosmmkfihwd")
    public suspend
    fun resourceGuardOperationDetails(values: List<Output<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qvjxlhuiqgtimgxf")
    public suspend fun resourceGuardResourceId(`value`: Output<String>) {
        this.resourceGuardResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("mitwgiskidvfqvtn")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("cbrvisnbprxfhcar")
    public suspend fun lastUpdatedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUpdatedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("dwmwcxadiqvocjce")
    public suspend
    fun resourceGuardOperationDetails(`value`: List<ResourceGuardOperationDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("klvcxtcfqjfubawn")
    public suspend
    fun resourceGuardOperationDetails(argument: List<suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kgxolbbskansbxab")
    public suspend fun resourceGuardOperationDetails(
        vararg
        argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wwchkydofbwdpotk")
    public suspend
    fun resourceGuardOperationDetails(argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("yxdliwecwdavrwwp")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: ResourceGuardOperationDetailArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("tqsdjkkpgsolfwyp")
    public suspend fun resourceGuardResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardResourceId = mapped
    }

    internal fun build(): ResourceGuardProxyBaseArgs = ResourceGuardProxyBaseArgs(
        description = description,
        lastUpdatedTime = lastUpdatedTime,
        resourceGuardOperationDetails = resourceGuardOperationDetails,
        resourceGuardResourceId = resourceGuardResourceId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/ResourceGuardProxyBaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property description
 * @property lastUpdatedTime
 * @property resourceGuardOperationDetails
 * @property resourceGuardResourceId
 */
public data class ResourceGuardProxyBaseArgs(
    public val description: Output<String>? = null,
    public val lastUpdatedTime: Output<String>? = null,
    public val resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null,
    public val resourceGuardResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs =
        com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .lastUpdatedTime(lastUpdatedTime?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationDetails(
                resourceGuardOperationDetails?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .resourceGuardResourceId(resourceGuardResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardProxyBaseArgs].
 */
@PulumiTagMarker
public class ResourceGuardProxyBaseArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var lastUpdatedTime: Output<String>? = null

    private var resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null

    private var resourceGuardResourceId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("rfhmqtgtmyubykmn")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("tmxsgudlnpvlixeh")
    public suspend fun lastUpdatedTime(`value`: Output<String>) {
        this.lastUpdatedTime = value
    }

    /**
     * @param value
     */
    @JvmName("aowkerwirycbkmvd")
    public suspend
    fun resourceGuardOperationDetails(`value`: Output<List<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = value
    }

    @JvmName("njcxxygcllxejawy")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: Output<ResourceGuardOperationDetailArgs>,
    ) {
        this.resourceGuardOperationDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("adgsgxdjltmwfris")
    public suspend
    fun resourceGuardOperationDetails(values: List<Output<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("rgofkvvvpyxxncds")
    public suspend fun resourceGuardResourceId(`value`: Output<String>) {
        this.resourceGuardResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("bkjrjnfexdhsxoxe")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("nufaorexntyimecl")
    public suspend fun lastUpdatedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUpdatedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("tjohpwblkpjeiaum")
    public suspend
    fun resourceGuardOperationDetails(`value`: List<ResourceGuardOperationDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("twqbawsdmabyaahh")
    public suspend
    fun resourceGuardOperationDetails(argument: List<suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wkjjsdgfeunqdtwb")
    public suspend fun resourceGuardOperationDetails(
        vararg
        argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("uklkkyvkkwhlhpjr")
    public suspend
    fun resourceGuardOperationDetails(argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("vjwtsowskdsqtovq")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: ResourceGuardOperationDetailArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("loegabmyqmpokrio")
    public suspend fun resourceGuardResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardResourceId = mapped
    }

    internal fun build(): ResourceGuardProxyBaseArgs = ResourceGuardProxyBaseArgs(
        description = description,
        lastUpdatedTime = lastUpdatedTime,
        resourceGuardOperationDetails = resourceGuardOperationDetails,
        resourceGuardResourceId = resourceGuardResourceId,
    )
}
